===================
salt.modules.yumpkg
===================

.. automodule:: salt.modules.yumpkg
    :members:
    :exclude-members: available_version, groupinstall, list_updates, get_locked_packages
